# My Python Library

This is a Python library that provides up-to-date insights and information on Hazel Lofty

## Installation

To install the library, you can use pip:

```
pip install Hazel
```

## Usage

Here is a simple example of how to use the library:

```python
import Hazel

# Returns age in years (float)
print(Hazel.getage()) # 46.07529089664613
```

## Contributing

If you would like to contribute to the library, please follow these steps:

1. Fork the repository.
2. Create a new branch (`git checkout -b feature-branch`).
3. Make your changes and commit them (`git commit -m 'Add new feature'`).
4. Push to the branch (`git push origin feature-branch`).
5. Create a new Pull Request.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.